@@ -43,7 +43,22 @@ sub update{
     my $self = shift;
     my $hash = shift;
     for(keys %$self){
-        $self->{$_} = $hash->{$_} if exists $hash->{$_} ;
+        if(exists $hash->{$_}){
+            if(defined $hash->{$_} and defined $self->{$_}){
+                if($hash->{$_} ne $self->{$_}){
+                    my $old_property = $self->{$_};
+                    my $new_property = $hash->{$_};
+                    $self->{$_} = $hash->{$_};
+                    $self->{_client}->emit("group_member_property_change"=>$self,$_,$old_property,$new_property);
+                }
+            }
+            elsif( ! (!defined $hash->{$_} and !defined $self->{$_}) ){
+                my $old_property = $self->{$_};
+                my $new_property = $hash->{$_};
+                $self->{$_} = $hash->{$_};
+                $self->{_client}->emit("group_member_property_change"=>$self,$_,$old_property,$new_property);
+            }
+        }
     }
     $self;
 }
